@@ -31,6 +31,7 @@ from zope.component import queryUtility
 # import local packages
 from ztfy.geoportal.location import GeoportalLocation
 from ztfy.skin.form import DialogEditForm
+from ztfy.utils.property import cached_property
 
 
 class GeoportalLocationEditForm(DialogEditForm):
@@ -47,12 +48,28 @@ class GeoportalLocationEditForm(DialogEditForm):
         else:
             return GeoportalLocation()
 
+    @cached_property
+    def config(self):
+        return queryUtility(IGeoportalConfigurationUtility)
+
     @property
     def geoportal_key(self):
-        config = queryUtility(IGeoportalConfigurationUtility)
+        config = self.config
         if config is not None:
             return config.api_key
 
+    @property
+    def geoportal_version(self):
+        config = self.config
+        if config is not None:
+            return config.version
+
+    @property
+    def geoportal_devel(self):
+        config = self.config
+        if config is not None:
+            return config.development
+
     @jsaction.handler(buttons['dialog_close'])
     def close_handler(self, event, selector):
         return '$.ZTFY.dialog.close();'
