@@ -10,6 +10,8 @@
 		 * Open Geoportal dialog box
 		 */
 		open: function(prefix, target) {
+			Geoportal = undefined;
+			OpenLayers = undefined;
 			$.ZTFY.dialog.open(target + '?prefix=' + prefix);
 		},
 
@@ -30,6 +32,7 @@
 			}
 			Geoportal.GeoRMHandler.getConfig([$(element).data('geoportal-api-key')], null, null, {
 				onContractsComplete: function() {
+					$($.ZTFY.geoportal).data('geoportal-config', this);
 					$.ZTFY.geoportal.loadMap(element);
 				}
 			});
@@ -168,6 +171,7 @@
 				proxy: 'http://api.ign.fr/geoportail/api/xmlproxy?url='
 			};
 
+			var target_id;
 			if (typeof(target) == 'string') {
 				target_id = target;
 				target = $('DIV[id="' + target_id + '"]');
